Frappy Programming Guide
========================

.. toctree::
   :maxdepth: 2

   introduction
   structure
   programming
   magic
   server
   tutorial
   reference
   frappy_psi
   frappy_demo
   frappy_mlz
   frappy_ess

* :ref:`genindex`

